@@ -11,9 +11,12 @@ from PIL import ImageTk,Image
 from tkinter import filedialog
 from os import path
 import GBARpy
-from GBARpy.MCPPicture import BeamSpot, gaussian_offset, import_config, import_image
+from GBARpy.MCPPicture import gaussian_offset, import_config, import_image
+from GBARpy.MCPPicture import BeamSpot
 from GBARpy.MCPPicture import MCPParams as mcpp
-import pickle
+#from MCPPicture import MCPParams as mcpp
+#from MCPPicture import BeamSpot
+import dill
 from matplotlib.backends.backend_tkagg import FigureCanvasTkAgg
 from matplotlib.figure import Figure
 import numpy as np
@@ -34,7 +37,7 @@ class MainWindow(tkinter.Tk):
         ### Fenetre principale
         tkinter.Tk.__init__(self)
         self.beamSpot = True
-        self.title("GBAR MCPy")
+        self.title("GBARPy")
         self.geometry("1000x600")
         self.resizable(True,True)
         self.canBeAnalysed = False
@@ -65,14 +68,18 @@ class MainWindow(tkinter.Tk):
         self.btn_analysis.grid(row=1,column=0)
         
         self.btn_mcpparams = tkinter.Button(self.frame0_c, text='MCP Parameters', command=self.defineMCPParams)
-        self.btn_mcpparams.grid(row=2,column=0)
+        self.btn_mcpparams.grid(row=3,column=0)
+        self.mcp_param_text = tkinter.StringVar()
+        self.mcp_param_text.set(self.mcp_param.__repr__())
+        self.mcp_param_label = tkinter.Label(self.frame0_c, textvariable=self.mcp_param_text)
+        self.mcp_param_label.grid(row=0,rowspan=4,column=2)
         
-        """
-        self.export = tkinter.Button(self.frame0_c, text='Export as PDF', command=self.exportAsPDF)
+        
+        self.export = tkinter.Button(self.frame0_c, text='Save analysis', command=self.exportAnalysis)
         self.export.grid(row=2,column=0)
         self.savedAs = tkinter.Label(self.frame0_c, textvariable=self.savedAsText)
         self.savedAs.grid(row=2,column=1)
-        """
+        
         
         add = path.join(static_addr,"GBAR_logo.png")
         img = Image.open(add)
@@ -96,7 +103,6 @@ class MainWindow(tkinter.Tk):
                        highlightbackground="black",highlightthickness=1)
         self.frame2.pack(side='right')
                 
-        
        
 
 
@@ -104,14 +110,21 @@ class MainWindow(tkinter.Tk):
     
     def open_img(self):
         try:
-            self.picadress = filedialog.askopenfilename(title='Open image')
+            self.picadress = filedialog.askopenfilename(title='Open image',
+                                                        filetypes = [("tif files","*.tif"),
+                                                                     ("jpg files","*.jpg"),
+                                                                     ("jpeg files","*.jpeg"),
+                                                                     ("png files","*.png"),
+                                                                     ("asc files","*.asc"),
+                                                                     ("bmp files","*.bmp")])
             self.picname.set(path.split(self.picadress)[-1])
             self.canBeAnalysed = True
             self.plotImage()
         except:
             print("Opening failed")
             self.canBeAnalysed = False
-        
+        self.plotImage()
+    
     
     def plotImage(self):
         def conv(a):
@@ -124,26 +137,31 @@ class MainWindow(tkinter.Tk):
             widget.destroy()
         if self.canBeAnalysed:   
             img = import_image(self.picadress)
-            fig = Figure(figsize=(6,5))
+            fig = Figure(figsize=(5,4))
             pplt = fig.add_subplot(111)
             pplt.imshow(img)
             pplt.set_xlabel('pixels',fontsize=fontsize)
             pplt.set_ylabel('pixels',fontsize=fontsize)
+            y = len(img)
+            x = len(np.transpose(img))
             if self.mcp_param.checkRatioIsSet():
                 pplt.set_xlabel('mm',fontsize=fontsize)
                 pplt.set_ylabel('mm',fontsize=fontsize)
-                
-                y = len(img)
-                x = len(np.transpose(img))
-                l = np.linspace(0,x,int(x/300))
+                l = np.linspace(0,x,4)
                 pplt.set_xticks(l)
                 l = conv(np.floor(l*self.mcp_param.ratio))
                 pplt.set_xticklabels(l)
-                
-                l = np.linspace(0,y,int(y/300))
+                l = np.linspace(0,y,4)
                 pplt.set_yticks(l)
                 l = conv(np.floor(l*self.mcp_param.ratio))
                 pplt.set_yticklabels(l)
+            if self.mcp_param.checkAllSet():
+                pplt.plot(self.mcp_param.x0,self.mcp_param.y0,'+',
+                         ms=15,mew=2,color='white')
+                pplt.set_xlim(0,x)
+                pplt.set_ylim(y,0)
+                X0,Y0 = self.circleXY(self.mcp_param.x0,self.mcp_param.y0,self.mcp_param.R0)
+                pplt.plot(X0,Y0,lw=3,color='white')
             canvas = FigureCanvasTkAgg(fig, master=self.frame1)
             canvas.draw()
             canvas.get_tk_widget().pack()
@@ -198,18 +216,34 @@ class MainWindow(tkinter.Tk):
         
         self.canBeExported = True
         
-    def exportAsPDF(self):
-        if self.canBeAnalysed == False:
-            self.open_img()
-            
-        if self.canBeExported == False:
-            self.analyse()
-        fig,fname = self.beamSpot.plot()
-        self.savedAsText.set("Saved as "+path.split(fname)[-1])
+    def exportAnalysis(self):
+        try:
+            if self.canBeAnalysed == False:
+                self.open_img()
+                
+            self.analyse()                
+            fname = filedialog.asksaveasfilename(filetypes=[("jpg files","*.jpg"),
+                                                            ("png files","*.png"),
+                                                            ("pdf files","*.pdf"),
+                                                            ("bmp files","*.bmp")])
+            if len(fname) > 0:
+                fig = self.beamSpot.plot()
+                fig.savefig(fname)
+                self.savedAsText.set("Saved as "+path.split(fname)[-1])
+        except:
+            print("Exportation failed")
+
         
     def defineMCPParams(self):
         MCPParamsWindow(self,self.mcp_param)
-
+        
+    def circleXY(self,x0,y0,R0):
+        """
+        To obtain cartesian coordinates of a circle
+        """
+        t = np.linspace(0,2*np.pi,100)
+        return x0 + R0*np.cos(t), y0 + R0*np.sin(t)
+    
 class MCPParamsWindow(tkinter.Toplevel):
     
     def __init__(self,master,mcp):
@@ -262,6 +296,7 @@ class MCPParamsWindow(tkinter.Toplevel):
             print(pp)
             self.mcp = pp
             self.master.mcp_param = pp
+            self.master.mcp_param_text.set(pp.__repr__())
         except:
             print("Setting failed")
         
@@ -275,7 +310,7 @@ class MCPParamsWindow(tkinter.Toplevel):
         try:
             pp = self.formToMCP()
             f = filedialog.asksaveasfile(mode='wb', defaultextension=".mcp")
-            pickle.dump(pp, f)
+            dill.dump(pp, f)
             print("Parameters saved as",f.name)
         except:
             print("Saving failed")
